;
; 'Arkrismas 2019'
;
; a.k.a  'A Free Fireplace for Xmas!'
;
; Released by Arkanix Labs in 2019
;
; www.arkanixlabs.com
;
; A (very) simple double screen demo,
; nothing more, nothing less!
;
; Code, graphics and music by aNdy/Cosine/AL/C64CD
;
; This source is formatted for the ACME cross assembler
; which can be downloaded from...
; http://sourceforge.net/projects/acme-crossass/
;
; The final build was compressed and squished using
; Exomizer 2 which can be downloaded from...
; http://hem.bredband.net/magli143/exo/
;
; Questions about this code or about how the binaries
; were created can be asked by emailing aNdy...
; andy@cosine.org.uk
;

; code begins now! ===============================

; the name and file format for the assembled program

		!to "arkrismas.prg",cbm

; drag in some charset, sprite and music binaries!	

		* = $0400
		!binary "data/screen.scnr"

		* = $1000
music	!binary "data/music.prg",,2

		* = $0800
		!binary "data/charset.chr"

		* = $2000
		!binary "data/sprites.spr"
		
; position of the raster interrupt(s) on-screen

raster_1_pos	= $00			; start of screen
raster_2_pos	= $32			; start of visible screen
raster_3_pos	= $4f			; end of snow
raster_4_pos	= $f9			; bottom of screen

; labels for keyboard location

pra  =  $dc00					; cia#1 (port register a)
prb  =  $dc01					; cia#1 (port register b)

; some more label assignments (variables)

raster_num			= $50		; raster counter stores which split we are working in
sync				= $51		; interupt sync variable
scroll_x1			= $52		; message 1 scroller screen position
scroll_pos1			= $53		; msg 1 scroller position - $02 bytes used
scroll_x2			= $55		; msg 2 scroller screen position
scroll_pos2			= $56		; msg 2 scroller position - $02 bytes used
colourwash_count	= $58		; counter for colour wash effect
colourwash_timer	= $59		; timer for colour wash effect
anim_timer			= $5a		; timer for sprite animation
snow_timer			= $5b		; timer for sprite movement
fade_tmr			= $5c		; timer for the merry xmas logo fade
fade_cnt			= $5d		; counter for the fade effect
fireplace			= $5e		; fireplace mode off/on
fire_timer			= $5f		; timer for fire place animation
fire_cnt			= $60		; counter for fireplace animation
twinkle_timer		= $61		; timer for star twinkles animation
twinkle_cnt			= $62		; counter for star twinkles animation
video_type			= $63		; 1=pal, 2=ntsc

; entry point for the code

		* = $2c00				

; stop interrupts, disable the roms and set up nmi and irq interrupt pointers		
				
code_entry

		sei						; disable maskable IRQs
		
; detect what machine type is being used...
; pal machines will open the border!

start_scan

		lda $d012
linecmp
		cmp $d012
		beq linecmp
		bmi start_scan
		adc #$00
		lsr
		bcs isntsc
		lsr
		bcs isoldntsc
		ldx #$00			; check drean or pal
		lda #$10
l
		inx
		cmp $d012
		bne l
		cpx #$70
		bcc ispal
isdrean
		lda #$02
		sta video_type		; video = ntsc
		jmp detect_dun
isntsc	
		lda #$02
		sta video_type		; video = ntsc
		jmp detect_dun
isoldntsc
		lda #$02
		sta video_type		; video = ntsc
		jmp detect_dun
ispal
		lda #$01
		sta video_type		; video = pal

detect_dun
		
		lda #$35				; kill EVERYTHING (MWHAHA!) except $f000-$ffff
		sta $01
		
; setup nmi

		lda #<nmi				; some nmi stuff
		sta $fffa
		lda #>nmi
		sta $fffb
		
; setup irq's

		lda #<int				; some irq stuff
		sta $fffe
		lda #>int
		sta $ffff

		lda #$7f
		sta $dc0d				; disable timer interrupts which can be generated by the two CIA chips
		sta $dd0d				; the kernal uses such an interrupt to flash the cursor and scan
								; the keyboard, so we better stop it

		lda $dc0d				; by reading this two registers we negate any pending CIA irqs.
		lda $dd0d				; if we don't do this, a pending CIA irq might occur after we
								; finish setting up our irq. we don't want that to happen.

		lda #raster_1_pos		; starting point of raster on screen ($00)
		sta $d012

		lda #$1b				; as there are more than 256 rasterlines, the topmost bit of $d011 serves as
		sta $d011				; the 9th bit for the rasterline we want our irq to be triggered.
		
		lda #$01
		sta $d019				; clear interupt bit
		sta $d01a				; tell vicii to generate interupt

		lda #$35				; turn off basic and kernal rom thus
		sta $01					; c64 now sees RAM everywhere except at $d000-$e000
		
		lda #$12				; use our custom font charset, ta very much!
		sta $d018

		cli

; first run screen setup =========================		

; note: the main screen ram is compiled direct to $0400
; so there is no screen printing here!

; set some border/background colours
	
        lda #$00				; load 0 for black
		sta $d021				; store to background! change colour!
		sta $d020				; store to border! change colour!

; no garbage in open borders please...		
		
		sta $3fff		

; set the main screen active on first run		
	
		sta fireplace

; clear out the colour ram in case		
		
		ldx #$00				; zero x register		
clrcolram						; clear colour ram loop!
		sta $d800,x
		sta $d900,x
		sta $da00,x
		sta $dae8,x		
		inx
		bne clrcolram

; load the colour ram xmas table values into the colour ram		
				
		ldx #$00					; zero x register
printcolramxmas_loop				; load whatever is in the colour
		lda colour_ram_xmas,x		; ram table and write to the
		sta $d800,x					; colour ram
		lda colour_ram_xmas+250,x
		sta $d800+250,x	
		lda colour_ram_xmas+500,x
		sta $d800+500,x	
		lda colour_ram_xmas+750,x
		sta $d800+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne printcolramxmas_loop	; all written? no? loop back!	

; reset the message scroller for first run

		jsr scroll_reset1		; reset 'scroller' subroutine
		jsr scroll_reset2		; reset 'scroller' subroutine		
		
		lda #$50
		sta scroll_x1
		sta scroll_x2			
		
; prepare the music for first run		
		
		lda #$00				; setup the driver to
		jsr music+$00			; play the title music
		
; set up raster handler for first raster at the top of the screen
		
		lda #$01
		sta raster_num
		sta twinkle_timer
		
; main runtime code =========================================

; first loop runs the main merry xmas screen

xmas_loop
								; call these subroutines...
		jsr sync_wait			; wait until irq finishes!
		
		jsr write_message1		; write the credit/greet message
		jsr write_message2		; write the personal messages
		
								; lets check the 'f' key
		lda #$fb 				; test $dc00 bit row 2 ($fb)
        sta pra
        lda prb
      
        cmp #$df				; key 'f' pressed?
		bne xmas_loop			; no, go back to main loop         
								; yes?
		
; set up the fireplace!								
		
		lda #$00				; turn off
		sta $d015				; all 8 sprites!
		lda #$01				; set fireplace mode on!
		sta fireplace

; draw the fireplace surround

		ldx #$00					; zero x register
printscrnramf_loop					; load up whatver is in the screen
		lda screen_ram_fire,x		; ram fire table and write to the
		sta $0400,x					; screen ram
		lda screen_ram_fire+250,x
		sta $0400+250,x
		lda screen_ram_fire+500,x
		sta $0400+500,x
		lda screen_ram_fire+750,x
		sta $0400+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne printscrnramf_loop		; all written? no? loop back!
									; yes? then...
		ldx #$00					; zero x register
printcolramf_loop					; load whatever is in the colour
		lda colour_ram_fire,x		; ram fire table and write to the
		sta $d800,x					; colour ram
		lda colour_ram_fire+250,x
		sta $d800+250,x	
		lda colour_ram_fire+500,x
		sta $d800+500,x	
		lda colour_ram_fire+750,x
		sta $d800+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne printcolramf_loop		; all written? no? loop back!				

; fireplace is setup, so lock into a loop!		
		
fire_loop

		jmp fire_loop					
								

; subroutines called from above code =====================		

; update 'scrolling' message subroutine --------------------- 
		
write_message1
	
		ldx scroll_x1
		cpx #$26
		bcs scroll_cnt1

; fetch a character from the text table

scroll_read1

		ldy #$00
		lda (scroll_pos1),y
		bne scroll_write1
		
		jsr scroll_reset1
		
		jmp scroll_read1

; write that character to the screen
		
scroll_write1

		sta $0451,x

; update the text position

		inc scroll_pos1+$00
		bne *+$04
		inc scroll_pos1+$01

; store the current text position		
		
scroll_cnt1

		inx
		stx scroll_x1
		
		rts						; return to where this was called from

; reset the scroll message		
				
scroll_reset1

		lda #<greet_text1
		sta scroll_pos1+$00
		lda #>greet_text1
		sta scroll_pos1+$01
		
		rts						; return to where this was called from

				
write_message2
	
		ldx scroll_x2
		cpx #$26
		bcs scroll_cnt2

; fetch a character from the text table

scroll_read2

		ldy #$00
		lda (scroll_pos2),y
		bne scroll_write2
		
		jsr scroll_reset2
		
		jmp scroll_read2

; write that character to the screen
		
scroll_write2

		sta $07c1,x

; update the text position

		inc scroll_pos2+$00
		bne *+$04
		inc scroll_pos2+$01

; store the current text position		
		
scroll_cnt2

		inx
		stx scroll_x2
		
		rts						; return to where this was called from

; reset the scroll message		
				
scroll_reset2

		lda #<greet_text2
		sta scroll_pos2+$00
		lda #>greet_text2
		sta scroll_pos2+$01
		
		rts						; return to where this was called from	

; flames animation draw subroutines -------------------------- 		

drawflames0

	    ldx #$00
fanimloop0
	    lda colour_ram_flames0,x
		sta $d8ce,x
	    lda colour_ram_flames0+28,x		
		sta $d8ce+40,x
	    lda colour_ram_flames0+56,x	
		sta $d8ce+80,x
	    lda colour_ram_flames0+84,x
		sta $d8ce+120,x
	    lda colour_ram_flames0+112,x
		sta $d8ce+160,x	  			    		
	    lda colour_ram_flames0+140,x
		sta $d8ce+200,x
	    lda colour_ram_flames0+168,x
		sta $d8ce+240,x
	    lda colour_ram_flames0+196,x
		sta $d8ce+280,x
	    lda colour_ram_flames0+224,x
		sta $d8ce+320,x
	    lda colour_ram_flames0+252,x
		sta $d8ce+360,x
	    lda colour_ram_flames0+280,x
		sta $d8ce+400,x							 			 		 			  
		inx
		cpx #$1c
		bne fanimloop0
		
		rts

drawflames1		
				
	    ldx #$00
fanimloop1
	    lda colour_ram_flames1,x
		sta $d8ce,x
	    lda colour_ram_flames1+28,x		
		sta $d8ce+40,x
	    lda colour_ram_flames1+56,x	
		sta $d8ce+80,x
	    lda colour_ram_flames1+84,x
		sta $d8ce+120,x
	    lda colour_ram_flames1+112,x
		sta $d8ce+160,x	  			    		
	    lda colour_ram_flames1+140,x
		sta $d8ce+200,x
	    lda colour_ram_flames1+168,x
		sta $d8ce+240,x
	    lda colour_ram_flames1+196,x
		sta $d8ce+280,x
	    lda colour_ram_flames1+224,x
		sta $d8ce+320,x
	    lda colour_ram_flames1+252,x
		sta $d8ce+360,x
	    lda colour_ram_flames1+280,x
		sta $d8ce+400,x							 			 		 			  
		inx
		cpx #$1c
		bne fanimloop1
		
		rts		

drawflames2		
				
	    ldx #$00
fanimloop2
	    lda colour_ram_flames2,x
		sta $d8ce,x
	    lda colour_ram_flames2+28,x		
		sta $d8ce+40,x
	    lda colour_ram_flames2+56,x	
		sta $d8ce+80,x
	    lda colour_ram_flames2+84,x
		sta $d8ce+120,x
	    lda colour_ram_flames2+112,x
		sta $d8ce+160,x	  			    		
	    lda colour_ram_flames2+140,x
		sta $d8ce+200,x
	    lda colour_ram_flames2+168,x
		sta $d8ce+240,x
	    lda colour_ram_flames2+196,x
		sta $d8ce+280,x
	    lda colour_ram_flames2+224,x
		sta $d8ce+320,x
	    lda colour_ram_flames2+252,x
		sta $d8ce+360,x
	    lda colour_ram_flames2+280,x
		sta $d8ce+400,x							 			 		 			  
		inx
		cpx #$1c
		bne fanimloop2
		
		rts
		
drawflames3	
				
	    ldx #$00
fanimloop3
	    lda colour_ram_flames3,x
		sta $d8ce,x
	    lda colour_ram_flames3+28,x		
		sta $d8ce+40,x
	    lda colour_ram_flames3+56,x	
		sta $d8ce+80,x
	    lda colour_ram_flames3+84,x
		sta $d8ce+120,x
	    lda colour_ram_flames3+112,x
		sta $d8ce+160,x	  			    		
	    lda colour_ram_flames3+140,x
		sta $d8ce+200,x
	    lda colour_ram_flames3+168,x
		sta $d8ce+240,x
	    lda colour_ram_flames3+196,x
		sta $d8ce+280,x
	    lda colour_ram_flames3+224,x
		sta $d8ce+320,x
	    lda colour_ram_flames3+252,x
		sta $d8ce+360,x
	    lda colour_ram_flames3+280,x
		sta $d8ce+400,x							 			 		 			  
		inx
		cpx #$1c
		bne fanimloop3
		
		rts					
				
; irq sync wait subroutine ---------------------------------- 
	   	 
sync_wait						; wait for sync update in irq code!
		lda #$00				; waits until the sync flag is
		sta sync				; set at the end of the interupt
sw_loop							; code further down.
		cmp sync				; no code in the main loop above
		beq sw_loop				; is executed until the interupt
								; has run it's course!
		rts
	
; end subroutines =====================================		
			

; IRQ interrupt code =================================

int
		pha  
		txa
		pha
		tya
		pha
		
		lda $d019
		and #$01
		sta $d019
		bne intr_trigd
		
		jmp irq_exit			; no interupt triggered? exit irq code!
		
; an interrupt has triggered!?!
; which split should we run? let's check...

intr_trigd

		lda raster_num			; load up the raster_num variable
		
		cmp #$02				; is it set to '2'?
		bne *+$05				; no? then jump down to check for '3'
		jmp irq_rout2			; yes? jump down to irq_rout2!
		
		cmp #$03				; is it set to '3'?
		bne *+$05				; no? then jump down and run '1'
		jmp irq_rout3			; yes? jump down to irq_rout3!
		
		cmp #$04				; is it set to '4'?
		bne *+$05				; no? then jump down and run '1'
		jmp irq_rout4			; yes? jump down to irq_rout4!		

; raster split 1 code -------------------------------

irq_rout1						; top section of the screen

; set interrupt handler ready for split 2

		lda #$02				; next run through this interupt code,
		sta raster_num			; split 2 should execute, a bit
		lda #raster_2_pos		; further down...
		sta $d012	

; are we in xmas or fireplace mode?		
		
		lda fireplace
		cmp #$00
		bne fire_bords1
		
		lda #$01				; change colour to white background
		sta $d021
		
		jmp maestro_please
		
fire_bords1			

		lda #$00				; black background
		sta $d021		
		
; play some music
		
maestro_please

		jsr music+$03			; play tune!		

; split 1 is done, exit irq interrupt		
					
		jmp irq_exit			; now exit the interupt!
		
; raster split 2 code ------------------------------------

irq_rout2

; set interrupt handler ready for split 3
	
		lda #$03
		sta raster_num
		lda #raster_3_pos
		sta $d012

; are we in xmas or fireplace mode?		
		
		lda fireplace
		cmp #$00
		bne fire_bords2
				
		lda #$00				; black background
		sta $d021		

		jmp irq_exit
		
fire_bords2		

		lda #$00				; change colour to black border
		sta $d020				; and black background
		sta $d021		
				
		jmp irq_exit			; now exit the interupt!		

; raster split 3 code ------------------------------------

irq_rout3

; set interrupt handler ready for split 4		

		lda #$04
		sta raster_num
		lda #raster_4_pos
		sta $d012
		
; should the main screen be active or the fireplace?

		lda fireplace			; is fireplace "1" active ?
		cmp #$00				; no?
		beq merry_xmas_code		; beq to merry xmas screen
								; yes?
		jmp fire_place_code		; jump down to fireplace code!

; run the merry xmas screen bits and bobs!		
		
merry_xmas_code

; set up and position the hardware sprites
		
		lda #$ff				; turn on..
		sta $d015				; all 8 sprites!
		sta $d01b				; put behind background		
		lda #$00				; make these sprites
		sta $d01c				; hires				
				
; snow sprites plotter!		
		
sprite_plotter		
		ldx #$00
		ldy #$00
sprite_plot
		lda sprite_x,x
		asl
		ror $d010
		sta $d000,y
		lda sprite_y,x
		sta $d001,y
		iny
		iny
		lda sprite_col,x
		sta $d027,x
		lda sprite_def,x
		sta $07f8,x		
		inx
		cpx #$08
		bne sprite_plot
		
; snow sprites animation routine!	
				
		ldx anim_timer				; load up the anim_timer
		inx							; increase it by '1'
		cpx #$06					; is the timer equal to '6' yet?
		bne anim_skip				; no? don't update animation!
									; yes? better do some animation then!
		ldx #$00
au_loop
		lda sprite_def,x
		clc
		adc #$01
		cmp sprite_anime,x
		bne au_skip
		lda sprite_anims,x
au_skip
		sta sprite_def,x
		inx
		cpx #$08
		bne au_loop								
									; yes?
		ldx #$00					; load x register with '0'
anim_skip							; to reset anim_timer and...	
		stx anim_timer				; store x register to anim_timer
		
; snow sprites movement routine

		ldx snow_timer				; load up the snow move timer
		inx							; increase it by '1'
		cpx #$02					; is the timer equal to '2' yet?
		bne snow_move_skip			; no? don't update movement
									; yes? better do some moving then!
		ldx #$00
sprite_fall
		lda sprite_y,x
		clc
		adc sprite_speed,x
		sta sprite_y,x
		inx
		cpx #$08
		bne sprite_fall
		
		ldx #$00					; load x register with '0'
snow_move_skip						; to reset anim_timer and...	
		stx snow_timer				; store x register to snow move timer
		
; now let's "fade" the central merry xmas logo

		ldx fade_tmr			; load whatever is in the fade timer
		inx						; increase it!
		cpx #$05				; is it 5?
		bne fade_skip			; nope? skip the fade routine then!
		
		ldy fade_cnt			; load y register with fade_cnt
		lda logo_fade,y			; what's at position y in the fade table?

		ldx #$00
fade_loop
		sta $d941,x				; colour ram start location of "merry"
		sta $d969,x
		sta $d991,x
		sta $d9b9,x
								; gap between merry & xmas!
								
		sta $da31,x				; colour ram start location of "xmas"
		sta $da59,x
		sta $da81,x
		sta $daa9,x
		inx
		cpx #$18				; logo is 24 chars wide, so
		bne	fade_loop			; 24 writes are needed!

		lda fade_cnt			; load accum with fade_cnt
		inc fade_cnt			; increase it by 1
		cmp #$07				; is it equal to 8?
		bne reset_tmr			; no? go down to reset the timer
								; yes?
		lda #$00				; lets reset the fade_cnt
		sta fade_cnt			; with 0 to wrap the fade table
reset_tmr
		ldx #$00				; reset the timer to 0!	
fade_skip
		stx fade_tmr			; store x register to the fade timer							
		
; star twinkles char animation
				
		ldx twinkle_timer			; load up the twinkle_timer
		inx							; increase it by '1'
		cpx #$08					; is the timer equal to '4' yet?
		bne twinkle_skip			; no? don't update animation!
									; yes? better do some animation then!		
		lda twinkle_cnt				; which twinkle are we on?
		cmp #$00					; is it '0'?
		bne twinkle_1				; no? branch down to twinkle_1
									; yes? do twinkle_0
; do twinkle 0									

	    ldx #$00				; zero x register
twinkle_loop_1
		lda twinkle_cross,x		; load cross def table
		sta $0920,x				; save to mem location
		lda twinkle_star,x		; load star def table
		sta $0930,x				; save to mem location		
		inx
		cpx #$08				; all 8 bytes done?
		bne twinkle_loop_1		; no? do the next byte then!
		
		lda #$01
		sta twinkle_cnt	

		jmp twinkle_dun				; twinkle is done, jump down!

; do twinkle 1		
				
twinkle_1
													
	    ldx #$00				; zero x register
twinkle_loop_2
		lda twinkle_star,x		; load star def table
		sta $0920,x				; save to mem location
		lda twinkle_cross,x		; load cross def table
		sta $0930,x				; save to mem location		
		inx
		cpx #$08				; all 8 bytes done?
		bne twinkle_loop_2		; no? do the next byte then!
		
		lda #$00
		sta twinkle_cnt			

twinkle_dun							; twinkle code is all done!	
		ldx #$00					; reset the twinkle timer to 0!	
twinkle_skip
		stx twinkle_timer			; store x register to the twinkle timer		
		
				
		jmp colour_wash

; if in fireplace mode, none of the above is ever
; executed because a bne above jumps down here!		
				
fire_place_code

		ldx fire_timer				; load up the fire anim timer
		inx							; increase it by '1'
		cpx #$05					; is the timer equal to '3' yet?
		bne fire_anim_skip			; no? don't update animation
									; yes? better do some anim then!

		lda fire_cnt				; which animation are we drawing?
		cmp #$00					; frame 0?
		beq fanim0					; yes? goto fanim0!
		cmp #$01
		beq fanim1					; etc!
		cmp #$02
		beq fanim2
		cmp #$03
		beq fanim3

; diplay fire animation 0		
				
fanim0

		jsr drawflames0				; gosub draw frame0 subroutine...
		jmp fire_anim_dun			; then jump down to anim_dun!

; diplay fire animation 1		
		
fanim1

		jsr drawflames1				; etc
		jmp fire_anim_dun

; diplay fire animation 2		
		
fanim2				
		jsr drawflames2	
		jmp fire_anim_dun				

; diplay fire animation 3		
				
fanim3
		jsr drawflames3											
									
; fire animation is done, so check if the
; animation counter needs resetting and reset
; if so, then reset the animation timer!									
									
fire_anim_dun

		lda fire_cnt			; load the fire anim counter
		inc fire_cnt			; increase by 1
		cmp #$03				; is it '4'?
		bne reset_fire_tmr		; no? go down to reset the timer
								; yes?
		lda #$00				; lets reset the fire_cnt
		sta fire_cnt			; with 0 to wrap the animation
								; then
reset_fire_tmr					; reset the fire anim timer			
		ldx #$00				; load x register with '0'
fire_anim_skip					; to reset fire anim timer and...	
		stx fire_timer			; store x register to fire anim timer

; colour wash effect for certain message lines

colour_wash
		
		ldx #$00
colourwash_loop
		lda colourwash_off,x
		clc
		adc colourwash_count
		and #$0f
		tay

		lda fireplace
		cmp #$00
		bne colourwash_fireplace
		
		lda colourwash_blues,y
		sta $d851,x					; colour ram loc for msg line 1
		sta $dbc1,x					; colour ram loc for msg line 2

		jmp colourwash_cont
		
colourwash_fireplace
		lda colourwash_reds,y
		sta $d829,x					; colour ram loc for fireplace msg
		
colourwash_cont		
		inx
		cpx #$26
		bne colourwash_loop

		ldx colourwash_timer
		inx
		cpx #$03
		bcc exit_wash
		inc colourwash_count
		ldx #$00
exit_wash	
		stx colourwash_timer
		
		jmp irq_exit			; no interupt triggered? exit irq code!
		
; raster split 4 code ------------------------------------

irq_rout4

; set interrupt handler ready for split 1		

		lda #$01
		sta raster_num
		lda #raster_1_pos
		sta $d012
		
		lda video_type			; is this an ntsc machine?
		cmp #$02				; yes?
		beq set_sync			; skip open border code!
		
		lda #$00				; black background
		sta $d021		
		
; open the top and bottom borders		
				
		lda #$14
		sta $d011

		lda #$fc
		cmp $d012
		bne *-$03

		lda #$1b
		sta $d011
								
; all splits have run so now set the sync
; variable for main line code synchronisation

set_sync
		lda #$01					; set the sync flag to '1'		
		sta sync					; so the main code runs!
		
; restore registers and exit irq interrupt

irq_exit

		pla
		tay
		pla
		tax
		pla
nmi		rti

; end irq interrupt code =============================


; all data tables live here! ===============================

; text data for the rolling greetings

greet_text1
		!scr "in december 2019 arkanix labs delivers"
		!scr "you some *festive* cheer with a little"
		!scr "two screen creation, creativley titled"
		!scr "->> > a r k r i s m a s  2 0 1 9 < <<-"
		!scr "a.k.a.   a free fire place for xmas!!!"		
		!scr "                                      "
		!scr "code, graphics and music by -> ;n() <-"
		!scr "                                      "
		!scr " this little xmas demo is best viewed "
		!scr " with a pal machine, because then the "
		!scr " top and bottom borders will open for "
		!scr " the full 'experience'!  also, please "
		!scr " use an 8580 sid chip where possible! "
		!scr "                                      "				
		!scr "arkanix labs sends christmas merriment"
		!scr "to these *wonderful* people and groups"
		!scr "                                      "
		!scr "big, giant, sloppy xmas kisses to both"
		!scr " > c 6 4 c d    and    c o s i n e <  "
		!scr "                                      "		
		!scr "more formal handshakes and waves go to"
		!scr " absence  abyss connection  artstate  "
		!scr "   ate bit  atlantis  booze design    "  
		!scr "    camelot  censor design  chorus    "				
		!scr " booze design  camelot  chrome  cncd  "
		!scr " cpu  crescent  crest  covert bitops  "										
		!scr "defence force  dekadence  desire  dac "
		!scr "   dmagic  dual crew  exclusive on    "					
		!scr " fairlight  f4cg  fire  flat 3  focus "								
		!scr "    french touch   genesis project    "
		!scr "   gheymaid inc   hitmen   hoaxers    "		
		!scr "hokuto force  legion of doom  level 64"
		!scr "  maniacs of noise  mayday  meanteam  "				
		!scr "metalvotze  noname  nostalgia  nuance "			
		!scr "offence  onslaught  orb  oxyron  padua"			
		!scr "  performers  plush  ppcs  psytronik  "			
		!scr " reptilia   resource   secure   shape "	
		!scr "  side b  singular  slash  slipstream "			
		!scr "      success and trc    style        "			
		!scr " suicyco industries  taquart  tempest "			
		!scr " tek   triad   tristar and red sector "					
		!scr "  viruz  vision  wow  wrath designs   "			
		!scr "           xenon     xentax           "
		!scr "                                      "										 						 			
						
		!byte $00		; end of text marker
		
greet_text2
		!scr "                                      "
		!scr "> incoming messages from individuals <"
		!scr "                                      "			
		!scr "moloch now bashing away at the keys..."
		!scr "  merry christmas and happy new year  "
		!scr "   from the immortal statue moloch!   "
		!scr "where has the time gone? it seems this"
		!scr "year has flown past in the blink of an"
		!scr "eye.  this year raised many challenges"
		!scr " for my family, but i am hopeful that "
		!scr " the new year will be a much quieter  "
		!scr " affair.   on the c64 front, the new  "
		!scr "year represents a renewed energy and a" 
		!scr "return to our long standing projects. "
		!scr " best wishes to all for the new year! "		
		!scr "                                      "		
		!scr "warlock poking away at the keys now..."
		!scr "  here i am wishing everyone a merry  "
		!scr " christmas, see you all next year!!!! "		
		!scr "  maybe my first demo release too in  "			
		!scr " 2020!?    o.k., enough text, time to "
		!scr "  work on some new maps for 'crimson  "		
		!scr "  twilight' in this new year.  merry  "		
		!scr "christmas you filthy animals...       "			
		!scr "           ...and a happy new year!!!!"		   
		!scr "                                      "			
		!scr ";n() is now tapping away those keys..."
		!scr "can i first say a ** huge ** thanks to"
		!scr "t.m.r / cosine for all the support and"
		!scr "help he has given me during 2019 while"
		!scr "i've been trying to learn this strange"
		!scr "language called 6502!  thanks also fly"
		!scr "out to  motion / artstate for the very"
		!scr "supportive comments and kindly words!!"
		!scr "look out for my c64 game > chiller 2 <"
		!scr "that will be released by cosine during"
		!scr "2020!   if i ever get my finger out..."  
		!scr "                                      "		
		!scr "w0rm proding away at those keys now..."
		!scr "i've only just got enough time to wish"
		!scr "all of my family a merry christmas and"
		!scr "happy new year!  hopefully, you'll get"
		!scr "to see more graphics from me in 2020!!"
		!scr "                                      "			
		!scr "fuzz thumping away at the keys now...."
		!scr "  merry christmas to all...           "
		!scr "          ...and to all a good .byte  "		
		!scr "                                      "
		
		!byte $00		; end of text marker
	
; colour table for the merry xmas logo fade		
			
logo_fade
		!byte $0d,$05,$08,$09,$02,$08,$0a,$01		
		
; colour wash data tables for text colour cycling

colourwash_off
		!byte $00,$01,$02,$01,$00,$01,$02,$01
		!byte $08,$07,$06,$05,$04,$03,$02,$04
		!byte $06,$08,$0a,$0c,$0e,$00,$0f,$0e
		!byte $0d,$0c,$0b,$0a,$09,$08,$07,$06
		!byte $0c,$0c,$0b,$0a,$0b,$0c,$0c,$0e		

colourwash_blues
		!byte $06,$04,$0e,$0e,$03,$01,$0f,$03
		!byte $0f,$01,$03,$0e,$0e,$04,$06,$0f

colourwash_reds
		!byte $07,$02,$02,$01,$02,$02,$07,$01	
		!byte $02,$02,$07,$01,$07,$02,$02,$01			


; snow sprites data doth be hereth!		
				
sprite_x		!byte $0a,$10,$20,$30,$40,$50,$60,$6d
sprite_y		!byte $10,$60,$a0,$30,$d0,$20,$70,$85
sprite_col		!byte $01,$01,$01,$01,$01,$01,$01,$01
sprite_def		!byte $80,$84,$88,$8c,$80,$84,$88,$8c
sprite_anims	!byte $80,$84,$88,$8c,$80,$84,$88,$8c
sprite_anime	!byte $84,$88,$8c,$90,$84,$88,$8c,$90
sprite_speed	!byte $01,$03,$02,$05,$02,$03,$04,$01

; char definitions for star twinkles

twinkle_cross
		!byte $00,$50,$20,$50,$00,$00,$00,$00
		
twinkle_star
		!byte $00,$20,$70,$20,$00,$00,$00,$00		
		
; colour ram data table	for merry xmas screen	
		
colour_ram_xmas
!byte $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
!byte $01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01
!byte $00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $0B,$0B,$00,$00,$0C,$0B,$00,$01,$0B,$00,$00,$0F,$00,$00,$00,$0F,$00,$0B,$0B,$00,$00,$0C,$00,$00,$0F,$00,$0F,$00,$01,$00,$00,$00,$0B,$00,$00,$00,$00,$0F,$00,$00
!byte $00,$00,$00,$0F,$00,$00,$0B,$0B,$00,$00,$0B,$00,$00,$01,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$00,$01,$09,$09,$09,$09,$09,$09,$09,$09,$09,$00
!byte $00,$01,$01,$01,$01,$01,$01,$01,$00,$01,$01,$01,$01,$00,$01,$01,$01,$01,$01,$01,$00,$01,$01,$01,$00,$01,$00,$00,$00,$00,$00,$09,$09,$09,$09,$09,$09,$09,$09,$00
!byte $0C,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$0C,$0C,$00,$00,$00,$0B,$00,$00,$00,$0C,$0C,$00,$00,$00,$0F,$00,$0C,$00,$0F,$00,$0C,$00,$09,$00,$09,$00,$09,$09,$00,$0B
!byte $00,$01,$01,$01,$01,$01,$01,$01,$01,$01,$00,$01,$01,$01,$01,$02,$01,$01,$01,$01,$02,$01,$00,$00,$01,$00,$00,$0F,$00,$0B,$00,$09,$09,$09,$09,$09,$09,$00,$0B,$00
!byte $00,$02,$02,$02,$02,$02,$02,$02,$01,$01,$00,$02,$02,$01,$02,$02,$02,$02,$01,$02,$02,$02,$02,$02,$02,$00,$00,$0B,$00,$00,$0B,$00,$01,$01,$01,$01,$0F,$0F,$01,$00
!byte $0B,$02,$02,$00,$02,$02,$02,$02,$02,$02,$00,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$00,$0F,$00,$0F,$0B,$00,$09,$09,$01,$09,$09,$01,$0F,$00,$0B
!byte $00,$02,$02,$00,$02,$02,$02,$02,$01,$01,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$00,$02,$02,$00,$00,$00,$0C,$00,$00,$00,$01,$01,$01,$01,$01,$01,$01,$0F,$00
!byte $00,$02,$02,$00,$02,$02,$02,$02,$02,$02,$02,$02,$02,$00,$02,$02,$02,$02,$00,$02,$02,$00,$02,$02,$00,$00,$0C,$00,$0F,$00,$00,$0F,$0F,$01,$0F,$0F,$01,$01,$01,$00
!byte $0F,$0B,$00,$00,$00,$0F,$00,$00,$0B,$00,$00,$0B,$0F,$00,$00,$01,$00,$00,$00,$00,$0B,$01,$00,$00,$0B,$00,$00,$00,$08,$08,$08,$01,$00,$0F,$01,$00,$01,$01,$0F,$00
!byte $02,$01,$01,$02,$01,$02,$01,$01,$01,$01,$01,$01,$01,$01,$01,$02,$01,$01,$01,$01,$02,$01,$01,$01,$01,$00,$00,$08,$08,$08,$08,$08,$08,$08,$01,$01,$01,$01,$01,$00
!byte $01,$02,$02,$00,$02,$02,$02,$02,$02,$02,$02,$02,$02,$00,$02,$02,$02,$02,$00,$02,$00,$02,$02,$02,$02,$0F,$0F,$08,$01,$08,$08,$08,$08,$09,$01,$01,$0B,$01,$0F,$0F
!byte $02,$02,$02,$02,$02,$02,$02,$02,$00,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$00,$0B,$00,$01,$01,$01,$01,$01,$01,$01,$0C,$0B,$01,$0F,$00
!byte $0C,$02,$02,$00,$02,$02,$02,$02,$00,$02,$02,$02,$02,$00,$02,$02,$02,$01,$00,$02,$02,$00,$02,$02,$00,$00,$00,$0B,$00,$00,$0C,$0F,$01,$01,$0F,$0C,$01,$01,$0F,$0B
!byte $00,$02,$02,$02,$02,$02,$02,$02,$00,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$02,$00,$02,$02,$00,$0B,$0F,$00,$00,$01,$0B,$0C,$0F,$0F,$0C,$0B,$01,$01,$0F,$00
!byte $0B,$00,$00,$00,$00,$0F,$0F,$0B,$00,$0B,$00,$01,$00,$00,$00,$0B,$0B,$00,$00,$0B,$00,$01,$00,$00,$0B,$00,$00,$0B,$00,$01,$01,$0B,$0B,$0B,$0B,$01,$01,$0F,$0F,$00
!byte $00,$01,$01,$01,$00,$01,$01,$01,$01,$00,$01,$01,$01,$01,$01,$00,$01,$01,$01,$00,$01,$01,$01,$01,$01,$01,$0B,$00,$00,$0F,$01,$01,$01,$01,$01,$01,$0F,$0F,$0F,$00
!byte $00,$00,$00,$00,$0C,$00,$00,$00,$00,$00,$00,$0B,$00,$00,$00,$00,$00,$0B,$00,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$00,$0F,$01,$01,$01,$01,$0F,$0F,$0F,$0B,$00
!byte $00,$02,$02,$02,$00,$02,$02,$02,$02,$02,$00,$02,$02,$02,$02,$02,$02,$00,$02,$02,$02,$02,$02,$02,$02,$02,$02,$01,$01,$01,$00,$0F,$0F,$0F,$0F,$0F,$0F,$0B,$0F,$00
!byte $0F,$0F,$01,$01,$01,$01,$01,$01,$0F,$01,$01,$01,$0B,$01,$0B,$01,$01,$0B,$01,$01,$01,$01,$01,$01,$0F,$0F,$01,$0C,$00,$00,$0B,$01,$0C,$00,$0B,$00,$0C,$0B,$00,$00
!byte $00,$00,$00,$00,$0C,$0F,$00,$00,$0B,$00,$00,$00,$0B,$0B,$00,$00,$01,$00,$00,$00,$0F,$0C,$0B,$00,$00,$0B,$00,$00,$00,$0F,$0C,$00,$00,$00,$00,$00,$0C,$00,$00,$00
!byte $00,$00,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$01,$00,$00

screen_ram_fire
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $DF,$01,$12,$0B,$01,$0E,$09,$18,$20,$0C,$01,$02,$13,$20,$17,$09,$13,$08,$05,$13,$20,$19,$0F,$15,$20,$01,$20,$0D,$05,$12,$12,$19,$20,$18,$0D,$01,$13,$21,$21,$5F
!byte $A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0
!byte $E6,$E8,$E8,$E6,$CE,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$CD,$E6,$E8,$E6,$E8
!byte $A0,$A0,$A0,$E8,$E5,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$EA,$E8,$A0,$A0,$A0
!byte $A0,$A0,$AE,$E6,$E5,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$EA,$E6,$AE,$BA,$AE
!byte $A0,$BA,$BA,$E6,$E5,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$EA,$E6,$BA,$BA,$BA
!byte $E6,$E8,$E6,$E8,$CE,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$CD,$E8,$E6,$E8,$E8
!byte $A0,$A0,$A0,$E8,$E5,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$EA,$E8,$A0,$AE,$A0
!byte $BA,$A0,$A0,$E6,$E5,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$EA,$E6,$A0,$BA,$BA
!byte $BA,$AE,$BA,$E6,$E5,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$EA,$E6,$AE,$BA,$A0
!byte $E8,$E8,$E6,$E8,$CE,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$CD,$E8,$E6,$E8,$E6
!byte $A0,$A0,$AE,$E8,$E5,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$EA,$E8,$A0,$AE,$A0
!byte $A0,$A0,$BA,$E6,$E5,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$EA,$E6,$A0,$BA,$A0
!byte $AE,$BA,$BA,$E6,$E5,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$EA,$E6,$BA,$BA,$AE
!byte $E8,$E8,$E6,$E8,$CE,$20,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$20,$CD,$E8,$E6,$E8,$E8
!byte $A0,$AE,$A0,$E8,$E5,$20,$20,$62,$6F,$F8,$62,$6F,$62,$62,$62,$79,$62,$79,$6F,$79,$62,$62,$79,$79,$6F,$62,$62,$79,$62,$F8,$62,$6F,$62,$20,$20,$EA,$E8,$AE,$A0,$A0
!byte $A0,$BA,$A0,$E6,$E5,$20,$6A,$D7,$C4,$62,$C4,$C3,$E8,$C3,$C4,$C4,$C5,$C4,$C3,$C3,$62,$62,$C3,$C4,$C5,$D1,$C3,$C3,$C4,$C4,$E8,$C5,$E8,$75,$20,$EA,$E6,$BA,$AE,$A0
!byte $AE,$BA,$BA,$E6,$E5,$20,$E1,$C3,$C3,$C3,$C4,$C4,$D1,$C5,$C5,$C5,$C4,$C4,$C3,$C3,$C3,$C3,$C4,$C4,$C4,$E2,$E2,$FB,$C3,$C3,$C4,$C5,$C3,$61,$20,$EA,$E6,$BA,$BA,$AE
!byte $E8,$E8,$E6,$E8,$CE,$20,$7C,$E6,$C5,$C5,$C4,$C3,$E8,$C3,$C4,$C4,$C4,$C4,$C4,$C6,$E8,$E6,$C6,$C4,$FC,$62,$62,$E8,$C4,$D1,$C3,$C6,$E6,$7E,$20,$CD,$E8,$E6,$E8,$E8
!byte $68,$68,$68,$68,$68,$68,$7C,$20,$43,$44,$45,$44,$43,$43,$44,$45,$43,$43,$43,$44,$46,$43,$43,$44,$44,$43,$44,$45,$43,$44,$43,$43,$20,$7E,$68,$68,$3B,$0E,$28,$29
!byte $AE,$A0,$CE,$AE,$A0,$AE,$A0,$A0,$A0,$A0,$BA,$AE,$A0,$CE,$BB,$A0,$A0,$BA,$BA,$A0,$A0,$BA,$A0,$BA,$AE,$A0,$A0,$CD,$A0,$AE,$A0,$A0,$A0,$BA,$AE,$A0,$AE,$CD,$A0,$AE
!byte $A0,$CE,$E8,$E8,$E8,$A0,$E8,$A0,$E8,$E8,$E8,$A0,$CE,$E8,$E8,$A0,$E8,$A0,$E8,$E8,$E8,$A0,$E8,$A0,$E8,$E8,$A0,$E8,$CD,$A0,$E8,$E8,$A0,$E8,$A0,$E8,$E8,$E8,$CD,$A0
!byte $CE,$A0,$A0,$A0,$A0,$A0,$A0,$E6,$E6,$E6,$A0,$CE,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$E6,$E6,$E6,$A0,$A0,$A0,$A0,$A0,$A0,$A0,$CD,$A0,$A0,$E6,$E6,$E6,$A0,$A0,$A0,$A0,$CD
!byte $E8,$E8,$E8,$E8,$E8,$E8,$E6,$E6,$E8,$E8,$CE,$E8,$E6,$E8,$E6,$E8,$E8,$E6,$E8,$E8,$E8,$E6,$E6,$E8,$E6,$E8,$E8,$E6,$E8,$E8,$CD,$E8,$E8,$E8,$E6,$E6,$E8,$E8,$E8,$E8

colour_ram_fire
!byte $0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$00,$0B,$0B,$0B,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0B,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0B,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0C,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0C,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0C,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0C,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0C,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0C,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0C,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0C,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0C,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0C,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0C,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0C,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0C,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$0C,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0C,$00,$00,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$00,$00,$0C,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0C,$0C,$00,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$08,$00,$0C,$0C,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0C,$0C,$00,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$00,$0C,$0C,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0C,$00,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$00,$0C,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0B,$0B,$09,$00,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$09,$00,$09,$0B,$0B,$0B,$0B,$0B,$0B
!byte $0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F,$0F
!byte $0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C,$0C
!byte $0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B
!byte $0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B,$0B

colour_ram_flames0
!byte $00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$02
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$02,$00,$00
!byte $00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$02,$00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$0A,$00,$00,$02,$00,$00,$0A,$00,$00,$02,$00,$0A,$00,$00,$0A,$00,$00,$02,$0A,$00,$00,$00,$00,$00,$00,$00,$02
!byte $02,$07,$02,$00,$0A,$02,$0A,$07,$00,$00,$0A,$07,$07,$0A,$00,$07,$0A,$07,$0A,$02,$00,$02,$0A,$00,$02,$00,$02,$0A
!byte $07,$07,$0A,$0A,$07,$0A,$0A,$0A,$00,$02,$07,$07,$01,$07,$0A,$07,$07,$01,$07,$07,$0A,$0A,$07,$0A,$0A,$02,$0A,$02
!byte $0A,$07,$0A,$07,$01,$07,$0A,$07,$0A,$07,$01,$07,$01,$01,$07,$01,$01,$01,$01,$07,$0A,$07,$01,$07,$07,$0A,$07,$0A
!byte $0A,$07,$0A,$07,$01,$07,$0A,$07,$0A,$07,$01,$07,$01,$01,$07,$01,$01,$01,$01,$07,$0A,$07,$01,$07,$07,$0A,$07,$0A
!byte $02,$0A,$07,$01,$01,$07,$07,$0A,$07,$01,$01,$07,$01,$01,$01,$01,$07,$01,$07,$07,$07,$01,$01,$07,$01,$07,$0A,$02
!byte $00,$02,$0A,$07,$07,$0A,$0A,$0A,$07,$07,$07,$01,$01,$07,$07,$07,$0A,$07,$0A,$02,$0A,$07,$01,$01,$01,$07,$02,$00

colour_ram_flames1
!byte $00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$02,$00,$02,$00,$00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$02,$00,$00,$00,$02,$00,$02,$00,$00,$00,$00,$02,$00,$00,$02,$00,$00,$00,$02,$00,$00,$00,$00,$02,$00,$00,$02
!byte $02,$0A,$02,$00,$02,$00,$02,$0A,$00,$00,$02,$00,$0A,$02,$00,$0A,$02,$00,$02,$0A,$00,$00,$02,$00,$02,$00,$00,$02
!byte $02,$07,$02,$00,$0A,$02,$0A,$0A,$02,$00,$0A,$0A,$07,$0A,$00,$07,$0A,$07,$0A,$02,$00,$02,$0A,$02,$02,$00,$02,$0A
!byte $07,$0A,$0A,$0A,$07,$0A,$0A,$07,$00,$02,$07,$07,$01,$07,$0A,$01,$07,$01,$07,$07,$0A,$0A,$07,$0A,$07,$02,$0A,$02
!byte $0A,$07,$0A,$07,$01,$07,$0A,$07,$0A,$07,$01,$07,$01,$01,$01,$07,$01,$01,$01,$07,$0A,$07,$01,$07,$01,$07,$07,$0A
!byte $0A,$07,$07,$01,$01,$07,$07,$07,$0A,$07,$01,$07,$01,$01,$07,$07,$07,$01,$07,$07,$0A,$07,$01,$07,$07,$0A,$07,$02
!byte $02,$0A,$07,$07,$01,$07,$07,$0A,$07,$01,$07,$07,$07,$01,$01,$07,$07,$07,$01,$07,$07,$01,$07,$07,$01,$07,$02,$02
!byte $00,$02,$0A,$07,$07,$01,$07,$0A,$07,$01,$07,$01,$01,$07,$07,$07,$07,$07,$07,$01,$07,$07,$01,$01,$07,$07,$0A,$00
!byte $00,$00,$02,$07,$01,$01,$07,$0A,$0A,$07,$0A,$07,$01,$01,$07,$07,$01,$07,$01,$01,$07,$01,$01,$01,$07,$0A,$02,$00

colour_ram_flames2
!byte $00,$02,$00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$02
!byte $00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$02,$00,$00,$02,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$02,$00,$00,$00,$0A,$02,$0A,$00,$00,$02,$00,$02,$02,$00,$00,$02,$00,$00,$02,$00,$00,$0A,$00,$02,$00,$00,$02
!byte $02,$0A,$02,$0A,$02,$02,$0A,$0A,$02,$00,$02,$0A,$07,$0A,$00,$0A,$0A,$07,$0A,$02,$00,$02,$07,$02,$02,$00,$02,$0A
!byte $07,$0A,$07,$07,$0A,$0A,$0A,$07,$00,$02,$02,$07,$07,$01,$0A,$07,$07,$07,$07,$0A,$07,$0A,$07,$0A,$01,$02,$0A,$02
!byte $07,$07,$0A,$07,$07,$07,$0A,$07,$0A,$07,$0A,$07,$01,$07,$0A,$0A,$07,$01,$07,$07,$07,$0A,$07,$07,$07,$0A,$07,$0A
!byte $0A,$07,$0A,$07,$01,$07,$07,$07,$0A,$07,$07,$01,$01,$07,$0A,$07,$01,$01,$01,$07,$07,$07,$01,$07,$07,$07,$0A,$02
!byte $02,$0A,$07,$07,$01,$01,$07,$0A,$07,$0A,$07,$07,$01,$07,$07,$07,$01,$07,$01,$07,$07,$01,$01,$01,$07,$07,$02,$02
!byte $02,$02,$0A,$07,$01,$07,$07,$0A,$07,$0A,$0A,$07,$01,$01,$07,$07,$07,$07,$01,$01,$07,$07,$01,$07,$07,$07,$0A,$02
!byte $00,$02,$02,$07,$07,$07,$0A,$0A,$07,$07,$0A,$0A,$07,$07,$01,$07,$07,$01,$07,$07,$07,$07,$07,$07,$07,$0A,$02,$00

colour_ram_flames3
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$02
!byte $00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$02,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$02,$00,$00,$00,$02,$00,$00,$02,$00,$00,$02,$02,$00,$00,$02,$00,$00
!byte $00,$02,$02,$0A,$02,$00,$00,$02,$00,$00,$02,$0A,$07,$0A,$00,$0A,$02,$07,$0A,$02,$00,$02,$07,$02,$02,$00,$02,$00
!byte $0A,$0A,$07,$07,$0A,$0A,$07,$07,$02,$0A,$02,$07,$01,$07,$0A,$07,$07,$01,$07,$0A,$07,$0A,$07,$0A,$07,$02,$0A,$02
!byte $07,$07,$0A,$07,$01,$07,$0A,$07,$0A,$0A,$0A,$07,$07,$07,$0A,$0A,$07,$07,$01,$07,$0A,$07,$07,$07,$0A,$0A,$07,$0A
!byte $0A,$07,$0A,$07,$01,$01,$07,$0A,$0A,$0A,$07,$0A,$07,$07,$0A,$07,$0A,$07,$07,$07,$0A,$07,$0A,$07,$07,$0A,$0A,$02
!byte $02,$0A,$07,$07,$07,$07,$07,$0A,$07,$0A,$07,$0A,$07,$01,$07,$0A,$0A,$07,$07,$01,$07,$07,$0A,$07,$07,$0A,$07,$02
!byte $00,$02,$0A,$07,$07,$01,$07,$0A,$07,$07,$07,$07,$07,$01,$07,$0A,$07,$01,$01,$01,$01,$07,$07,$01,$07,$07,$02,$00
!byte $00,$02,$02,$07,$01,$01,$07,$07,$0A,$07,$01,$01,$07,$01,$01,$07,$01,$01,$01,$01,$07,$07,$01,$01,$01,$0A,$02,$00

; end of code!!! ========================================================================
